<?php 
// Do not allow direct access to the file.
if( ! defined( 'ABSPATH' ) ) {
    exit;
}

if ( ! function_exists( 'maxstart_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 */
	function maxstart_setup() {
		/*
		 * Make theme available for translation.
		 */
		load_theme_textdomain( 'maxstart', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 */
		add_theme_support( 'post-thumbnails' );


			// This theme uses wp_nav_menu() in one location.
		add_theme_support( 'nav-menus' );
		register_nav_menu('primary', esc_html__( 'Primary Menu', 'maxstart' ) );
		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'maxstart_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 50,
			'width'       => 140,
			'flex-width'  => true,
			'flex-height' => false,
		) );
	}
endif;
add_action( 'after_setup_theme', 'maxstart_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 */
function maxstart_content_width() {
	// This variable is intended to be overruled from themes.
	$GLOBALS['content_width'] = apply_filters( 'maxstart_content_width', 640 );
}
add_action( 'after_setup_theme', 'maxstart_content_width', 0 );

/**
 * Register widget area.
 */
function maxstart_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'maxstart' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'maxstart' ),
		'before_widget' => '<div id="%1$s" class="sidebar-item %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="sidebar-title">',
		'after_title'   => '</h3>',
	) );
		
		register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area', "maxstart"),
		'id' => 'maxstart-footer-widget-area',
		'description' => esc_html__( 'The footer widget area', "maxstart"),
		'before_widget' => '<div class="%2$s footer-widget col-md-3 col-sm-6 col-xs-12">',
		'after_widget' => '</div>',
		'before_title' => '<div class="widget-title"><h3>',
		'after_title' => '</h3></div>',
	));	
	
	
}
add_action( 'widgets_init', 'maxstart_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function maxstart_scripts() {
	wp_enqueue_style( 'maxstart-style', get_stylesheet_uri() );
	wp_enqueue_style( 'maxstart-font', 'https://fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,400i,600,700');
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.css');
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.css');
	wp_enqueue_style( 'slicknav', get_template_directory_uri() . '/css/slicknav.css');

	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.js', array('jquery'), '', true );
    wp_enqueue_script( 'popper', get_template_directory_uri() . '/js/popper.js', array(), '', true );
    wp_enqueue_script( 'slicknav', get_template_directory_uri() . '/js/slicknav.js', array(), '', true );
    wp_enqueue_script( 'active', get_template_directory_uri() . '/js/active.js', array(), '', true );
    
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'maxstart_scripts' );

/**
 * Admin scripts and styles.
 */

/**
 * Includes
 */
 
get_template_part('library/custom-header');
get_template_part('library/template-tags');
get_template_part('library/customizer');
get_template_part('library/before-header');
get_template_part('library/header-after');



/**
 * Adds custom classes to the array of body classes.
 */

function maxstart_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'maxstart_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function maxstart_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'maxstart_pingback_header' );

/**
 * Maxstart Fix skip link focus in IE11.
 *
 * This does not enqueue the script because it is tiny and because it is only for IE11,
 * thus it does not warrant having an entire dedicated blocking script being loaded.
 *
 * @link https://git.io/vWdr2
 */
function maxstart_skip_link_focus_fix() {
	// The following is minified via `terser --compress --mangle -- js/skip-link-focus-fix.js`.
	?>
	<script>
	/(trident|msie)/i.test(navigator.userAgent)&&document.getElementById&&window.addEventListener&&window.addEventListener("hashchange",function(){var t,e=location.hash.substring(1);/^[A-z0-9_-]+$/.test(e)&&(t=document.getElementById(e))&&(/^(?:a|select|input|button|textarea)$/i.test(t.tagName)||(t.tabIndex=-1),t.focus())},!1);
	</script>
	<?php
}
add_action( 'wp_print_footer_scripts', 'maxstart_skip_link_focus_fix' );